==> mx-packageinstaller-pkglist_19.05.13.tar.xz: mx-packageinstaller-pkglist/grub-customizer.pm <==
<?xml version="1.0"?>
<app>

<category>
Utility
</category>

<name>
grub customizer
</name>

<description>
   <am>customize grub boot menu</am>
   <ar>customize grub boot menu</ar>
   <bg>customize grub boot menu</bg>
   <ca>customize grub boot menu</ca>
   <cs>customize grub boot menu</cs>
   <da>tilpas grub-opstartsmenu</da>
   <de>Individualisierung des GRUB Bootmenüs</de>
   <el>προσαρμόστε το μενού εκκίνησης grub</el>
   <en>customize grub boot menu</en>
   <es>customize grub boot menu</es>
   <et>customize grub boot menu</et>
   <eu>customize grub boot menu</eu>
   <fa>customize grub boot menu</fa>
   <fi>customize grub boot menu</fi>
   <fr>personnalisation du menu de démarrage du grub</fr>
   <he_IL>customize grub boot menu</he_IL>
   <hi>customize grub boot menu</hi>
   <hr>customize grub boot menu</hr>
   <hu>customize grub boot menu</hu>
   <id>customize grub boot menu</id>
   <is>customize grub boot menu</is>
   <it>personalizzare il menu del boot di grub</it>
   <ja_JP>customize grub boot menu</ja_JP>
   <ja>customize grub boot menu</ja>
   <kk>customize grub boot menu</kk>
   <ko>customize grub boot menu</ko>
   <lt>customize grub boot menu</lt>
   <mk>customize grub boot menu</mk>
   <nb>customize grub boot menu</nb>
   <nl>pas grub boot menu aan</nl>
   <pl>dostosowywuje menu rozruchowe grub</pl>
   <pt_BR>customize grub boot menu</pt_BR>
   <pt>customize grub boot menu</pt>
   <ro>customize grub boot menu</ro>
   <ru>настройка меню загрузки GRUB</ru>
   <sk>customize grub boot menu</sk>
   <sl>customize grub boot menu</sl>
   <sq>customize grub boot menu</sq>
   <sr>customize grub boot menu</sr>
   <sv>anpassa grub boot meny</sv>
   <tr>customize grub boot menu</tr>
   <uk>customize grub boot menu</uk>
   <zh_CN>customize grub boot menu</zh_CN>
   <zh_TW>customize grub boot menu</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
grub-customizer
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
grub-customizer
</uninstall_package_names>
</app>

==> mx-packageinstaller-pkglist_19.09.03.tar.xz: mx-packageinstaller-pkglist/grub-customizer.pm <==
<?xml version="1.0"?>
<app>

<category>
Utility
</category>

<name>
grub customizer
</name>

<description>
   <am>customize grub boot menu</am>
   <ar>customize grub boot menu</ar>
   <bg>customize grub boot menu</bg>
   <ca>personalitza el menú d'arrencada GRUB</ca>
   <cs>customize grub boot menu</cs>
   <da>tilpas grub-opstartsmenu</da>
   <de>Individualisierung des GRUB Bootmenüs</de>
   <el>προσαρμόστε το μενού εκκίνησης grub</el>
   <en>customize grub boot menu</en>
   <es>Personalizar el menú de arranque grub</es>
   <et>customize grub boot menu</et>
   <eu>customize grub boot menu</eu>
   <fa>customize grub boot menu</fa>
   <fi>customize grub boot menu</fi>
   <fr>personnalisation du menu de démarrage du grub</fr>
   <he_IL>customize grub boot menu</he_IL>
   <hi>customize grub boot menu</hi>
   <hr>customize grub boot menu</hr>
   <hu>customize grub boot menu</hu>
   <id>customize grub boot menu</id>
   <is>customize grub boot menu</is>
   <it>personalizzare il menu del boot di grub</it>
   <ja_JP>customize grub boot menu</ja_JP>
   <ja>customize grub boot menu</ja>
   <kk>customize grub boot menu</kk>
   <ko>customize grub boot menu</ko>
   <lt>customize grub boot menu</lt>
   <mk>customize grub boot menu</mk>
   <nb>customize grub boot menu</nb>
   <nl>pas grub boot menu aan</nl>
   <pl>dostosowywuje menu rozruchowe grub</pl>
   <pt_BR>Personalizar o menu do grub</pt_BR>
   <pt>Personalizar o menu do grub</pt>
   <ro>customize grub boot menu</ro>
   <ru>настройка меню загрузки GRUB</ru>
   <sk>customize grub boot menu</sk>
   <sl>customize grub boot menu</sl>
   <sq>customize grub boot menu</sq>
   <sr>customize grub boot menu</sr>
   <sv>anpassa grub boot meny</sv>
   <tr>customize grub boot menu</tr>
   <uk>customize grub boot menu</uk>
   <zh_CN>customize grub boot menu</zh_CN>
   <zh_TW>customize grub boot menu</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
grub-customizer
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
grub-customizer
</uninstall_package_names>
</app>
